<?php

/**
 * affiche un lecteur video ou audio qui s'inscrit au maxima dans son bloc parent
 *
 * {up media_plyr=yt | code=bTqVqk7FSmY }
 * {up media_plyr=vimeo | code=bTqVqk7FSmY }
 * <b>media_plyr</b> : precisez yt ou youtube ou vimeo
 * <b>code</b>  : il s'agit du code figurant dans l'URL de la vidéo.
 * -
 * {up media_plyr=video | poster=url image | mp4 | webm | vtt | download }
 * <b>media_plyr</b> : video pour indiquer l'URL vers la video.
 * <b>poster</b> : nom de l'image fixe
 * <b>mp4, webm, vtt, download</b> : si URL non spécifiée, elle sera déduite de celle pour 'poster'
 * -
 * {up media_plyr=audio | mp3=url fichier mp3 | ogg}
 * <b>media_plyr</b> : audio
 * <b>mp3</b> : url vers fichier MP3 (obligatoire)
 * <b>ogg</b> : si URL non spécifiée, elle sera déduite de celle pour 'MP3'
 * -
 * @author      DANEEL & LOMART
 * @version     v1.0 du 30-09-2017
 * @license   <a href="http://www.gnu.org/licenses/gpl-3.0.html" target="_blank">GNU/GPLv3</a>
 */
defined('_JEXEC') or die;

class media_plyr extends upAction {

    function init() {
        $this->load_file('plyr.css'); //v 2.0.13
        $this->load_file('plyr.js'); //v 2.0.13

        $js_code = 'var instances = plyr.setup({ debug: true });';
        $this->load_jquery_code($js_code);

        return true;
    }

    function run() {

        // lien vers la page de demo (vide=page sur le site de UP)
        $this->set_demopage();

        $options_def = array(
            __class__ => '', // type de lecture : youtube, vimeo, video ou audio
            'id' => '',
            'code' => '', // code de la video (à la fin de l'url youtube ou vimeo)
            'poster' => '', // URL de l'image (obligatoire)
            'mp4' => '', // URL du fichier MP4. Si vide, on utilise le nom de poster
            'webm' => '', // URL du fichier WEBM. Si vide, on utilise le nom de poster
            'vtt' => '', // URL du fichier VTT pour sous-titrage. Si vide, on utilise le nom de poster
            'download' => '', // URL du fichier téléchargeable. Si vide, on utilise le nom du fichier MP4
            'mp3' => '', // URL du fichier audio mp3. (obligatoire)
            'ogg' => '', // URL du fichier audio ogg. Si vide, on utilise le nom du fichier MP3
            'class' => '', // classe(s) ajoutée(s) au bloc extérieur
            'style' => '' // style inline ajouté au bloc extérieur
        );

        // ==== si video en video ou audio, on affecte les variables pour un eventuel debug
        // si appel par vimeo, audio ou video
        $this->set_option_user_if_true(__class__, $this->actionUserName);

        // si video, on affecte les variables pour debug
        if ($this->options_user[__class__] == "video") {
            if (!isset($this->options_user['poster'])) {
                return $this->info_debug('option POSTER obligatoire pour video');
            }
            $name = substr($this->options_user['poster'], 0, strrpos($this->options_user['poster'], '.'));
            $this->set_option_user_if_true('mp4', $name . '.mp4');
            $this->set_option_user_if_true('webm', $name . '.webm');
            $this->set_option_user_if_true('vtt', $name . '.vtt');
            $this->set_option_user_if_true('download', $name . '.download');
        }

        // si audio, on affecte les variables pour debug
        if ($this->options_user[__class__] == "audio") {
            if (!isset($this->options_user['mp3'])) {
                return $this->info_debug('option MP3 obligatoire pour audio');
            }
            $name = substr($this->options_user['mp3'], 0, strrpos($this->options_user['mp3'], '.'));
            $this->set_option_user_if_true('ogg', $name . '.ogg');
        }

        // fusion et controle des options
        $options = $this->ctrl_options($options_def);

        switch ($options[__class__]) {
            case 'yt':
            case 'youtube':
                $out = '<div data-type="youtube" data-video-id="' . $options['code'] . '"></div>';
                break;

            case 'vimeo' :
                $out = '<div data-type="vimeo" data-video-id="' . $options['code'] . '"></div>';
                break;

            case 'video' :
                $out = '<video poster="' . $options['poster'] . '" controls crossorigin style="max-width:100%">';
                $out .= ($options['mp4'] > '') ? '<source src="' . $options['mp4'] . '" type="video/mp4">' : '';
                $out .= ($options['webm'] > '') ? '<source src="' . $options['webm'] . '" type="video/webm">' : '';
                $out .= ($options['vtt'] > '') ? '<track kind="captions" label="English" srclang="en" src="' . $options['vtt'] . '" default>' : '';
                $out .= ($options['download'] > '') ? '<a href="' . $options['download'] . '">download</a>' : '';
                $out .= '</video>';
                break;

            case 'audio' :
                $out = '<audio controls>';
                $out .= '<source src="' . $options['mp3'] . '" type="audio/mp3">';
                $out .= ($options['ogg'] > '') ? '<source src="' . $options['ogg'] . '" type="audio/ogg">' : '';
                $out .= '</audio>';
                break;

            default :
                $out = $this->info_debug($options[__class__] . ': argument invalide pour video');
        }

        if (($options['class'] > '') || ($options['style'] > '')) {
            $inner = $out;
            // attributs du bloc principal
            $attr_main = array();
            $attr_main['class'] = $options['class'];
            $attr_main['style'] = $options['style'];

            // code en retour
            $out = $this->set_attr_tag('div', $attr_main);
            $out .= $inner;
            $out .= '</div>';
        }

        return $out;
    }

// run
}

// class
